@@ -63,7 +63,7 @@
   #:use-module ((nyacc lex) #:select (cnumstr->scm))
   #:use-module ((nyacc util) #:select (ugly-print))
   #:re-export (*nyacc-version*)
-  #:version (2 02 3))
+  #:version (2 02 4))
 
 (define default-renamer (lambda (name ctxt) name))
 
@@ -283,16 +283,17 @@
 ;; The procedure @var{expand-tail} will expand the type in the field.
 ;; @end deffn
 (define-public (cnvt-fields fields expand-tail)
-  (define qq 'quasiquote)
-  (define uq 'unquote)
+  (define q 'quasiquote)
+  (define u 'unquote)
   (map
    (lambda (dent)
      (let* ((name (rename (car dent) 'field)) (udecl (cdr dent))
-	    (mdecl (udecl->mdecl (udecl-rem-type-qual udecl)))
+            (xdecl (expand-typerefs udecl (*udict*) (*defined*)))
+	    (mdecl (udecl->mdecl (udecl-rem-type-qual xdecl)))
 	    (type (expand-tail (md-tail mdecl))))
        (if (and (pair? type) (eq? 'cbitfield (car type)))
-           `(,qq (,(and=> name string->symbol) (,uq ,(cadr type)) ,(caddr type)))
-           `(,qq (,(and=> name string->symbol) (,uq ,type))))))
+           `(,q (,(and=> name string->symbol) (,u ,(cadr type)) ,(caddr type)))
+           `(,q (,(and=> name string->symbol) (,u ,type))))))
    (clean-and-dictize-fields fields)))
 
 ;; Should be processed with canize-enum-def-list first
@@ -408,10 +409,16 @@
   (let ((defined (*defined*)))
     (match mtail
       (`((pointer-to) (typename ,name))
+       (when (string= name "FILE")
+         (sferr "have FILE, but why?\n")
+         )
        (let ((name (rename name 'type)))
-         (if (dmem? (w/* name) defined)
-             (strings->symbol name "*")
-             `(cpointer (delay ,(string->symbol name))))))
+         (cond
+          ((member name def-def-list)
+           `(cpointer (cbase ',(string->symbol name))))
+          ((dmem? (w/* name) defined)
+           (strings->symbol name "*"))
+          (else `(cpointer (delay ,(string->symbol name)))))))
       (`((pointer-to) (void))
        `(cpointer 'void))
       (`((pointer-to) (fixed-type "char"))
